@@ -6,6 +6,5 @@ import pytest
 
 
 def test():
-    """Initiate einsteinpy testing
-    """
+    """Initiate einsteinpy testing"""
     pytest.main([os.path.dirname(os.path.abspath(__file__))])
